@@ -35,7 +35,7 @@ impl Defer {
         }
     }
 
-    #[cfg(tokio_taskdump)]
+    #[cfg(feature = "taskdump")]
     pub(crate) fn take_deferred(&self) -> Vec<Waker> {
         let mut deferred = self.deferred.borrow_mut();
         std::mem::take(&mut *deferred)
